@@ -2,13 +2,14 @@ import logging
 from datetime import datetime
 from typing import Optional, List, Tuple
 
-from peek_plugin_eventdb._private.storage.EventDBModelSetTable import EventDBModelSetTable
-from peek_plugin_eventdb.tuples import loadPublicTuples
-from peek_plugin_eventdb.tuples.EventDBEventTuple import EventDBEventTuple
 from sqlalchemy.dialects import postgresql
 from vortex.Payload import Payload
 from vortex.Tuple import TUPLE_TYPES_BY_NAME
 
+from peek_plugin_eventdb._private.storage.EventDBModelSetTable import EventDBModelSetTable
+from peek_plugin_eventdb.tuples import loadPublicTuples
+from peek_plugin_eventdb.tuples.EventDBEventTuple import EventDBEventTuple
+
 logger = logging.getLogger(__name__)
 
 
@@ -55,11 +56,28 @@ class EventDBImportEventsInPgTask:
             plpy.debug("ModelSet with key %s doesn't exist" % modelSetKey)
             return 0
 
-        # Now insert the events
+        # Now delete the events
         cls._deleteEvents(plpy, modelSetId, eventKeys)
 
         return len(eventKeys)
 
+    @classmethod
+    def updateAlarmFlags(cls, plpy,
+                         modelSetKey: str,
+                         eventKeys: List[str],
+                         alarmFlag: bool) -> int:
+
+        # Get the model set id
+        modelSetId = cls.getModelSetId(plpy, modelSetKey, createIfMissing=False)
+        if modelSetId is None:
+            plpy.debug("ModelSet with key %s doesn't exist" % modelSetKey)
+            return 0
+
+        # Now insert the events
+        cls._updateAlarmFlags(plpy, modelSetId, eventKeys, alarmFlag)
+
+        return len(eventKeys)
+
     @classmethod
     def getModelSetId(cls, plpy, modelSetKey, createIfMissing) -> Optional[int]:
         msTbl = EventDBModelSetTable.__table__
@@ -87,11 +105,15 @@ class EventDBImportEventsInPgTask:
             cls._deleteEvents(plpy, modelSetId, keys)
 
         plan = plpy.prepare('''INSERT INTO pl_eventdb."EventDBEvent"
-                                ("dateTime", "key", "modelSetId", value)
-                                VALUES ($1, $2, $3, $4);''',
-                            ["timestamp with time zone", "text", "integer", "jsonb"])
+                                ("dateTime", "key", "isAlarm",
+                                        "modelSetId", value)
+                                VALUES ($1, $2, $3,
+                                        $4, $5);''',
+                            ["timestamp with time zone", "text", "boolean",
+                             "integer", "jsonb"])
         for event in events:
-            plpy.execute(plan, [event.dateTime, event.key, modelSetId, event.value])
+            plpy.execute(plan, [event.dateTime, event.key, event.isAlarm,
+                                modelSetId, event.value])
 
     @classmethod
     def _deleteEvents(cls, plpy, modelSetId: int, eventKeys: List[str]):
@@ -100,3 +122,17 @@ class EventDBImportEventsInPgTask:
                     AND "modelSetId" = %s;'''
         sql %= (', '.join("'%s'" % k for k in eventKeys), modelSetId)
         plpy.execute(sql)
+
+    @classmethod
+    def _updateAlarmFlags(cls, plpy, modelSetId: int, eventKeys: List[str],
+                          alarmFlag: bool):
+        sql = '''UPDATE pl_eventdb."EventDBEvent"
+                 SET "isAlarm" = %(isAlarm)s
+                 WHERE key in (%(keys)s)
+                    AND "modelSetId" = %(modelSetId)s;'''
+        sql %= dict(
+            modelSetId=modelSetId,
+            keys=', '.join("'%s'" % k for k in eventKeys),
+            isAlarm=str(alarmFlag).lower()
+        )
+        plpy.execute(sql)
